@@ -50,7 +50,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gdk-pixbuf/gdk-pixbuf-io.h>
 
 #ifdef HAVE_EXIF
 #include <libexif/exif-data.h>
@@ -246,6 +245,7 @@ eog_image_init (EogImage *img)
 	img->priv->modified = FALSE;
 	img->priv->status_mutex = g_mutex_new ();
 	img->priv->status = EOG_IMAGE_STATUS_UNKNOWN;
+        img->priv->metadata_status = EOG_IMAGE_METADATA_NOT_READ;
 	img->priv->is_monitored = FALSE;
 	img->priv->undo_stack = NULL;
 	img->priv->trans = NULL;
@@ -859,6 +859,7 @@ eog_image_real_load (EogImage *img,
 		g_free (mime_type);
 
 		if (error != NULL) {
+			g_clear_error (error);
 			g_set_error (error,
 				     EOG_IMAGE_ERROR,
 				     EOG_IMAGE_ERROR_VFS,
@@ -954,6 +955,7 @@ eog_image_real_load (EogImage *img,
 						       0,
 						       priv->width,
 						       priv->height);
+                                priv->metadata_status = EOG_IMAGE_METADATA_NOT_AVAILABLE;
                         }
 
 			first_run = FALSE;
@@ -974,6 +976,7 @@ eog_image_real_load (EogImage *img,
 					eog_image_set_xmp_data (img, md_reader);
 #endif
 					set_metadata = FALSE;
+                                        priv->metadata_status = EOG_IMAGE_METADATA_READY;
 				}
 
 				if (data2read == EOG_IMAGE_DATA_EXIF)
@@ -1323,7 +1326,7 @@ tmp_file_move_to_uri (EogImage *image,
 		      GError **error)
 {
 	gboolean result;
-	GError **ioerror = NULL;
+	GError *ioerror = NULL;
 
 	result = g_file_move (tmpfile,
 			      file,
@@ -1332,20 +1335,20 @@ tmp_file_move_to_uri (EogImage *image,
 			      NULL,
 			      (GFileProgressCallback) transfer_progress_cb,
 			      image,
-			      ioerror);
+			      &ioerror);
 
 	if (result == FALSE) {
-		if (g_error_matches (*ioerror, G_IO_ERROR,
+		if (g_error_matches (ioerror, G_IO_ERROR,
 				     G_IO_ERROR_EXISTS)) {
 			g_set_error (error, EOG_IMAGE_ERROR,
 				     EOG_IMAGE_ERROR_FILE_EXISTS,
 				     "File exists");
 		} else {
-		g_set_error (error, EOG_IMAGE_ERROR,
-			     EOG_IMAGE_ERROR_VFS,
-			     "VFS error moving the temp file");
+			g_set_error (error, EOG_IMAGE_ERROR,
+				     EOG_IMAGE_ERROR_VFS,
+				     "VFS error moving the temp file");
 		}
-		g_error_free (*ioerror);
+		g_clear_error (&ioerror);
 	}
 
 	return result;
@@ -1518,7 +1521,7 @@ static gboolean
 eog_image_copy_file (EogImage *image, EogImageSaveInfo *source, EogImageSaveInfo *target, GError **error)
 {
 	gboolean result;
-	GError *ioerror;
+	GError *ioerror = NULL;
 
 	g_return_val_if_fail (EOG_IS_IMAGE_SAVE_INFO (source), FALSE);
 	g_return_val_if_fail (EOG_IS_IMAGE_SAVE_INFO (target), FALSE);
@@ -1872,6 +1875,23 @@ eog_image_get_status (EogImage *img)
 	return img->priv->status;
 }
 
+/**
+ * eog_image_get_metadata_status:
+ * @img: a #EogImage
+ *
+ * Returns the current status of the image metadata, that is,
+ * whether the metadata has not been read yet, is ready, or not available at all.
+ *
+ * Returns: one of #EogImageMetadataStatus
+ **/
+EogImageMetadataStatus
+eog_image_get_metadata_status (EogImage *img)
+{
+        g_return_val_if_fail (EOG_IS_IMAGE (img), EOG_IMAGE_METADATA_NOT_AVAILABLE);
+
+        return img->priv->metadata_status;
+}
+
 void
 eog_image_data_ref (EogImage *img)
 {
